<?xml version="1.0" encoding="UTF-8"?>
<!-- $Id: rapport.xsl,v 1.1 2009/01/23 13:30:47 dickdeneer Exp $ -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<!-- Need to instruct the XSLT processor to use HTML output rules.
		See http://www.w3.org/TR/xslt#output for more details
	-->
	<xsl:output encoding="UTF-8" method="html"/>
	<!-- This first template matches our root element in the input file.
		This will trigger the generation of the HTML skeleton document.
		In between we let the processor recursively process any contained
		elements, which is what the apply-templates instruction does.
		We also pick some stuff out explicitly in the head section using
		value-of instructions.
	-->
	<xsl:template match="/config">
		<html>
			<head>
				<xsl:call-template name="styles"/>
				<title>
					<xsl:text>JCC</xsl:text>
				</title>
				<META content="{author/text()}" name="Author"/>
			</head>
			<body>
			    <h1><xsl:value-of select="environment"/></h1>
			    <h3><xsl:value-of select="description"/></h3>
			    <xsl:if test="graph">
			          <img src="cid:graph.png"/>
			    </xsl:if>
				<xsl:apply-templates select="checks"/>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="checks">
		<table class="data" cellspacing="1">
			<thead>
				<tr>
					<td>sel</td>
					<td>description</td>
					<td>result</td>
					<td>message</td>
					<td>totalTime</td>
				</tr>
			</thead>
			<tbody>
				<xsl:apply-templates select="check"/>
			</tbody>
		</table>
	</xsl:template>
	<!-- Match the chapter as h4 -->
	<xsl:template match="check">
	   <xsl:variable name="rowClass">
         <xsl:choose>
			   <xsl:when test="position() mod 2 = 0">even</xsl:when>
			    <xsl:otherwise>odd</xsl:otherwise>
	      </xsl:choose>
	    </xsl:variable>
      
		<tr class="{$rowClass}">
			<td>
			   <xsl:variable name="v_selected">
			      <xsl:value-of select="selected"/>
			   </xsl:variable>
				<xsl:choose>
			      <xsl:when test="$v_selected='true'"><img src="cid:checkbox.png" alt="X"/></xsl:when>
			      <xsl:otherwise><img src="cid:checkbox_empty.png" alt=""/></xsl:otherwise>
			   </xsl:choose>
			</td>
			<td>
				<xsl:value-of select="name"/>
			</td>
			<td>
			   <xsl:variable name="v_result">
			      <xsl:value-of select="result"/>
			   </xsl:variable>
			   <xsl:choose>
			      <xsl:when test="$v_result=-1"></xsl:when>
			       <xsl:when test="$v_result=0"><img src="cid:table_valid.png" alt="ok"/></xsl:when>
			       <xsl:when test="$v_result=2"><img src="cid:table_error.png" alt="error"/></xsl:when>
			        <xsl:otherwise><img src="cid:table_valid.png" alt="ok"/></xsl:otherwise>
			   </xsl:choose>
			</td>
			<td>
				<xsl:value-of select="shortMessage"/>
			</td>
			<td>
				<xsl:value-of select="totalTime"/>
			</td>
		</tr>
	</xsl:template>
	<xsl:template name="styles">
		<style type="text/css">
			<xsl:comment>
body { font-family: Arial,Helvetica,sans-serif; font-size: 76%; margin: 4px 1% 10px 1%; padding: 0; background: #fff; color: #006; min-width: 760px;position:relative;}

table {
border: 0px;
}
 
table.data th {
background-color: #DDD;
border-top: 1px;
border-left: 1px;
border-right: 1px;
border-color: blue;
padding: 4px 4px 4px 4px;
}

table.data { font-size: 1em; color: #333; border: 0px; margin: 0; padding: 0; }
table.data a { color: #333; }
table.data thead { font-weight:bold; }
table.data thead tr { background-color: #deeaf6; }
table.data tbody { }
table.data tbody tr.even { background-color: #f3f8fe; }
table.data tbody tr.odd { background-color: #ffffff; }
table.data td { padding: 4px 4px 4px 4px; vertical-align: top; }
td.toprow { padding: 4px 4px 4px 4px; vertical-align: top;background-color:#deeaf6; border-top-width:2px;}
</xsl:comment>
		</style>
	</xsl:template>
	<xsl:template name="script">
		<script>
//global variables for all three examples
var colors = new Array('#ffffff','#dddddd','#aaaaaa','#888888');
var bgcolor = 255; 			//starting bgcolor in decimal
var steps = 10;				//the factor, a distance between colors
var down = true;			//direction, if going up or down when calculating bgcolor value
var switchingPoint = 160;	//the numeric value where the foreground color need to change
var fgColorHi = "white";
var fgColorLo = "black";
/****************************************************************************************/
function alternate(id){ 
 if(document.getElementsByTagName){  
   var table = document.getElementById(id);   
   var rows = table.getElementsByTagName("tr");   
   for(i = 0; i &lt; rows.length; i++){           
 //manipulate rows 
     if(i % 2 == 0){ 
       rows[i].className = "even"; 
     }else{ 
       rows[i].className = "odd"; 
     }       
   } 
 } 
}
</script>
	</xsl:template>
</xsl:stylesheet>